==> khtml-4.97.0.zip: khtml-4.97.0/src/rendering/render_canvasimage.h <==
/*
 * Copyright (C) 2004, 2006, 2007 Apple Computer, Inc.  All rights reserved.
 * Copyright (C) 2005 Zack Rusin <zack@kde.org>
 * Copyright (C) 2007 Maksim Orlovich <maksim@kde.org>
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY APPLE COMPUTER, INC. ``AS IS'' AND ANY
 * EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE ARE DISCLAIMED.  IN NO EVENT SHALL APPLE COMPUTER, INC. OR
 * CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
 * EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
 * PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY
 * OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
 * OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

#ifndef RENDER_CANVASIMAGE_H
#define RENDER_CANVASIMAGE_H

#include "html/html_elementimpl.h"
#include "html/html_canvasimpl.h"
#include "rendering/render_replaced.h"
#include "dom/dom_string.h"

#include <QtCore/QMap>
#include <QImage>
#include <QPainter>

#include "imload/imagepainter.h"

namespace khtml
{

class RenderCanvasImage : public RenderReplaced
{
public:
    RenderCanvasImage(DOM::HTMLCanvasElementImpl *);

    virtual const char *renderName() const
    {
        return "RenderCanvasImage";
    }

    virtual void paint(PaintInfo &i, int tx, int ty);
    virtual void layout();
    virtual void updateFromElement();

    // don't even think about making this method virtual!
    DOM::HTMLCanvasElementImpl *element() const
    {
        return static_cast<DOM::HTMLCanvasElementImpl *>(RenderObject::element());
    }

private:
    khtmlImLoad::ImagePainter imagePainter;
};

} //namespace

#endif

==> khtml-5.36.0.zip: khtml-5.36.0/src/rendering/render_canvasimage.h <==
/*
 * Copyright (C) 2004, 2006, 2007 Apple Computer, Inc.  All rights reserved.
 * Copyright (C) 2005 Zack Rusin <zack@kde.org>
 * Copyright (C) 2007 Maksim Orlovich <maksim@kde.org>
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY APPLE COMPUTER, INC. ``AS IS'' AND ANY
 * EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE ARE DISCLAIMED.  IN NO EVENT SHALL APPLE COMPUTER, INC. OR
 * CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
 * EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
 * PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY
 * OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
 * OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

#ifndef RENDER_CANVASIMAGE_H
#define RENDER_CANVASIMAGE_H

#include "html/html_elementimpl.h"
#include "html/html_canvasimpl.h"
#include "rendering/render_replaced.h"
#include "dom/dom_string.h"

#include <QtCore/QMap>
#include <QImage>
#include <QPainter>

#include "imload/imagepainter.h"

namespace khtml
{

class RenderCanvasImage : public RenderReplaced
{
public:
    RenderCanvasImage(DOM::HTMLCanvasElementImpl *);

    const char *renderName() const Q_DECL_OVERRIDE
    {
        return "RenderCanvasImage";
    }

    void paint(PaintInfo &i, int tx, int ty) Q_DECL_OVERRIDE;
    void layout() Q_DECL_OVERRIDE;
    void updateFromElement() Q_DECL_OVERRIDE;

    // don't even think about making this method virtual!
    DOM::HTMLCanvasElementImpl *element() const
    {
        return static_cast<DOM::HTMLCanvasElementImpl *>(RenderObject::element());
    }

private:
    khtmlImLoad::ImagePainter imagePainter;
};

} //namespace

#endif
